@@ -2,6 +2,11 @@ from restfly.utils import dict_merge, url_validator
 import time
 
 
+def snake_to_camel(name):
+    name = name[0].lower() + name.title()[1:].replace("_", "")
+    return name
+
+
 def obfuscate_api_key(seed):
     now = int(time.time() * 1000)
     n = str(now)[-6:]
@@ -12,4 +17,4 @@ def obfuscate_api_key(seed):
     for j in range(0, len(str(r)), 1):
         key += seed[int(str(r)[j]) + 2]
 
-    return {'timestamp': now, 'key': key}
+    return {'timestamp': now, 'key': key}
\ No newline at end of file
